@@ -176,6 +176,13 @@ def simulations(
 def settings(
         ctx: typer.Context,
         organisation: str = typer.Option(None, help="Unique-id of the organisation to set as default"),
+        scenario_folder: Path = typer.Option(
+            None,
+            dir_okay=True,
+            writable=True,
+            resolve_path=True,
+            help="Specify a the folder for your scenario's.",
+        ),
         result_folder: Path = typer.Option(
             None,
             dir_okay=True,
@@ -194,7 +201,7 @@ def settings(
         if (
             ctx.obj.organisation_uuid
             and Confirm.ask(
-                f"Change current organisation {settings.organisation_uuid}?"
+                f"Change current organisation {ctx.obj.organisation_uuid}?"
             )
             or not ctx.obj.organisation_uuid
         ):
@@ -206,15 +213,22 @@ def settings(
             )
         else:
             organisation = ctx.obj.organisation_uuid
-    if not result_folder:
-        result_folder = click.prompt(
-            "Set default result folder",
-            default=ctx.obj.result_folder or "./results",
-            type=click.Path(dir_okay=True, writable=True, resolve_path=True),
+    if not scenario_folder:
+        default_scenario_path = ctx.obj.scenario_folder or Path("./scenarios").resolve()
+        print(default_scenario_path)
+        scenario_folder = PathPrompt.ask(
+            "Where do you keep your scenario files?",
+            default=default_scenario_path
         )
-
-    settings.organisation_uuid = organisation
-    settings.result_folder = result_folder
+    if not result_folder:
+        results_folder_default = ctx.obj.result_folder or Path("./results").resolve()
+        result_folder = PathPrompt.ask(
+            "Where do you want to store your result files?",
+            default=results_folder_default
+        )
+    ctx.obj.organisation_uuid = organisation
+    ctx.obj.result_folder = result_folder
+    ctx.obj.scenario_folder = scenario_folder
     console.print(
         f":heavy_check_mark: Default settings are saved in {ctx.obj.config_file}"
     )
